.. _cache_module:

:mod:`kazoo.recipe.cache`
----------------------------

.. automodule:: kazoo.recipe.cache

Public API
++++++++++

    .. autoclass:: TreeCache

        .. automethod:: start
        .. automethod:: close
        .. automethod:: listen
        .. automethod:: listen_fault
        .. automethod:: get_data
        .. automethod:: get_children

    .. autoclass:: TreeEvent
        :members:
        :show-inheritance:

    .. autoclass:: NodeData
        :members:
        :show-inheritance:
